### Name: samp.dist
### Title: Representation of a statistic's sampling distribution
### Aliases: samp.dist


### ** Examples

##Central limit theorem
exp.parent<-rexp(1000000)
par(mfrow=c(2,2),mar=c(4.4,4.5,1,0.5))
samp.dist(parent=exp.parent, s.size=1, R=100) ## n = 1
samp.dist(parent=exp.parent, s.size=5, R=100) ## n = 5
samp.dist(parent=exp.parent, s.size=10, R=100) ## n = 10
samp.dist(parent=exp.parent, s.size=50, R=100) ## n = 50 

##Distribution of t-statistics under valid and invalid assumptions
#valid
parent<-rnorm(100000)
t.star<-function(s.dist1,s.dist2,s.dist3,s.dist4,s.size=6,s.size2=s.size){
MSE<-(((s.size-1)*s.dist3)+((s.size2-1)*s.dist4))/(s.size+s.size2-2)
func.res<-(s.dist1-s.dist2)/(sqrt(MSE)*sqrt((1/s.size)+(1/s.size2)))
func.res}

samp.dist(parent, parent2=parent, s.size=6, R=1000, breaks=35,stat=mean,stat2=mean,stat3=var,stat4=var,xlab="t*", ylab="Relative frequency",func=t.star)
curve(dt(x,10),from=-6,to=6,add=TRUE,lwd=2)
legend("topleft",lwd=2,col=1,legend="t(10)")

#invalid; same means but different variances and other distributional characteristics.
parent<-runif(100000, min=0,max=2)
parent2<-rexp(100000)

samp.dist(parent, parent2=parent2, s.size=6, R=1000, breaks=35,stat=mean,stat2=mean,stat3=var,stat4=var,xlab="t*", ylab="Relative frequency",func=t.star)
curve(dt(x,10),from=-6,to=6,add=TRUE,lwd=2)
legend("topleft",lwd=2,col=1,legend="t(10)")



